<?php


/* MediaWiki extension point for NDR page metadata 
 *
 * The contents enclosed in this tag are treated as NDR
 * metadata describing the wiki page itself.  If the papge is
 * published in the NDR as a resource, this extension
 * mediates the metadata that describes it in the NDR 
 * 
 * Copyright (c) 2008 by Cornell University (email : systems@nsdl.org)
 * The program is distributed under the Educational Community License. 
 * Details can be found in the LICENSE file of this distribution.
 * 
 */

$wgExtensionFunctions[] = "initNDRExtension";
$wgExtensionCredits['specialpage'][] = array(
    'name' => 'NSDL Data Repository',
    'version' => '2007/04/07',
    'author' => 'Aaron Birkland',
    'url' => 'http://wiki.nsdl.org/index.php/Community:NSDLWiki',
    'description' => 'Publishing and editing resources in the NSDL Data Repository',
);

/* As per bug described in 
 * http://meta.wikimedia.org/w/index.php?title=Writing_a_new_special_page&oldid=545772 
 */
$wgExtensionFunctions[] = 'rmSetup';

require_once ("nsdl/NDRExtension/ResourceManager.php");

/* Register this extension with the appropriate hooks */
function initNDRExtension() {
	global $wgParser;
	global $wgHooks;
	global $wgSpecialPages;
	global $wgAutoloadClasses;
	global $wgExtensionFunctions;


	/*
	 * RepositoryManager: Creates a 'Special' page that allows for 
	 * the configuration, reporting, or other management of the wiki's 
	 * representation in the NDR.
	 */
	$wgAutoloadClasses['RepositoryManager'] = dirname(__FILE__) . '/nsdl/NDRExtension/RepositoryManager.php';
	$wgSpecialPages['RepositoryManager'] = 'RepositoryManager';
	
	/*
	 * ReferencedResourceManager: Creates a 'Special' page that allows for
	 * adding a referenced (i.e. non-wiki) resource to the NDR and/or defining metadata for it
	 */
	 $wgAutoloadClasses['ReferencedResourceManager'] = dirname(__FILE__) . '/nsdl/NDRExtension/ReferencedResourceManager.php';
	$wgSpecialPages['ReferencedResourceManager'] = 'ReferencedResourceManager';

	/*
	 * ResourceManager: Creates a repository tab ("Management Interface") 
	 * on every page that allows that resource 
	 * (or resources contained in the page) to
	 * be added, annotated, or described in the NDR
	 */
	$wgHooks['SkinTemplateTabs'][] = 'repositoryTab'; 			/* Hook for the tab itself */
	$wgHooks['UnknownAction'][] = 'manageRepository';			/* Tab action/contents */
	
	/* The following markup is 'private', i.e. a user should not use them */
	$wgParser->setHook('_nsdl:editMetadata', 'editMetadata'); 	/* Metadata editing */
	$wgParser->setHook('_nsdl:editRepositoryInfo', 'editRepositoryInfo'); 	/* Repository editing */
	$wgParser->setHook('_nsdl:addOrEditResource', 'addOrEditResourceLink');		/* Link to NDR resources */

}

/* Render the metadata enclosed in the tage into HTML */
function renderResource($input, $argv, & $parser) {
	return "<div id=\"toy\">Got resource as: <verb>$input</verb></div>";
}

function repositoryTab(& $skin, & $content_actions) {
	global $wgRequest, $wgTitle;
	$action = $wgRequest->getText('action');
	$content_actions['nsdl'] = array (
		'class' => ($action == 'manageRepository') ? 'selected' : '', 
		'text' => 'NSDL', 
		'href' => $wgTitle->getLocalUrl('action=manageRepository'));
	return true;
}

function manageRepository(& $action, & $article) {
	global $wgOut, $wgUser;
	$wgOut->clearHTML();
	$ns = $article->getTitle()->getNsText();
	if ($ns) $ns .= ":";
	if ($action != 'nsdlsearch') {
    	$wgOut->setPageTitle("NSDL interaction ({$ns}{$article->getTitle()->getText()})");
    	$manager = new NDRExtension_ResourceManager($article, $action);
    	try {
    	    $wgOut->addWikiText($manager->execute());
    	} catch (Exception $e) {
    		/* 
    		 * This will cause wiki processing to stop, 
    		 * and the error to be reported 
    		 */
    		return $e->getMessage();
    	}
	}
	return false;
}

/* 
 * Adds the Repository Manager to the list of special pages.  This is not the
 * usual way to do it, but apparently there is a MediaWiki bug as documented earlier
 */
function rmSetup() {
  global $wgMessageCache;
  $wgMessageCache->addMessage('repositorymanager', 'Repository Manager');
  $wgMessageCache->addMessage('referencedresourcemanager', 'Referenced Resource Manager');
}
?>
