<?php

/* MediaWiki extension point for NDR page metadata 
 *
 * The contents enclosed in this tag are treated as NDR
 * metadata describing the wiki page itself.  If the papge is
 * published in the NDR as a resource, this extension
 * mediates the metadata that describes it in the NDR 
 * 
 * Copyright (c) 2008 by Cornell University (email : systems@nsdl.org)
 * The program is distributed under the Educational Community License. 
 * Details can be found in the LICENSE file of this distribution.
 * 
 */

$wgExtensionFunctions[] = "initNSDLSearchExtension";
$wgExtensionCredits['specialpage'][] = array(
    'name' => 'NSDL Search',
    'version' => '2007/04/21',
    'author' => 'Elly Cramer',
    'url' => 'http://wiki.nsdl.org/index.php/Community:NSDLWiki',
    'description' => 'Enables searching of NSDL and inserting resource links',
);

/* As per bug described in 
 * http://meta.wikimedia.org/w/index.php?title=Writing_a_new_special_page&oldid=545772 
 */
$wgExtensionFunctions[] = 'nspSetup';

require_once ("nsdl/NSDLSearchExtension/SearchResultsDisplay.php");
require_once ("nsdl/NSDLSearchExtension/SearchNSDL.php");

/* Register this extension with the appropriate hooks */
function initNSDLSearchExtension() {
	global $wgParser;
	global $wgHooks;
	global $wgSpecialPages;
	global $wgAutoloadClasses;
	global $wgExtensionFunctions;

	/*
	 * SearchResultsDisplay: Creates a 'Special' page that provides NSDL search results
	 * for inserting links into articles in the edit page.
	 */
	//$wgAutoloadClasses['NSDLSearch'] = dirname(__FILE__) . '/nsdl/NSDLSearchExtension/SearchNSDL.php';
	$wgAutoloadClasses['SearchResultsDisplay'] = dirname(__FILE__) . '/nsdl/NDRExtension/SearchResultsDisplay.php';
	$wgSpecialPages['SearchResultsDisplay'] = 'SearchResultsDisplay';
	
	/*
	 * NSDLSearch creates a button on all edit pages
	 * and allows user to search the NDR and add resources.
	 */
	$wgHooks['BeforePageDisplay'][] = 'nsdlSearchJS';
	$wgHooks['UnknownAction'][] = 'nsdlsearchActionHook';	/* Adding action hook */
}

/*
 * Adding a js and search box to wiki edit pages
 */
function nsdlSearchJS () {
    $isNDRPopup = true;
    global $wgRequest, $wgServer, $wgOut, $wgJsMimeType, $wgScriptPath;
    global $nsdlResourcePath;
    $serverUrl = $wgServer . $wgScriptPath;
	$action = $wgRequest->getVal( 'action', false );
	$isSearchPopup = (eregi('Special:SearchResultsDisplay', $_SERVER['REQUEST_URI']));
	if ((eregi('Special:ReferencedResourceManager', $_SERVER['REQUEST_URI'])) || ($action != 'manageRepository')) {
	    $isNDRPopup = false;
    }
    // Verify we are in the wiki edit page and not the repository plugin
	if ($isNDRPopup == false) {
	    // call the search javascript
        $wgOut->addHTML( 
        	"<script type=\"{$wgJsMimeType}\" src=\"{$wgScriptPath}{$nsdlResourcePath}/NSDLSearchExtension.js\">"
        	. "</script>\n" 
        );
    	switch ($action) {
    	    case 'edit':
    	    case 'submit':
    	        // Name the parent window, but not the popup
    	        $wgOut->addHTML("<script type=\"{$wgJsMimeType}\" >"
            		. "name_nsdl_parent_window();"
            		. "</script>\n"
            		);
    	    case 'nsdlsearch':
            	// call the NSDL search box
            	$wgOut->addHTML(
            		"<script type=\"{$wgJsMimeType}\" >"
        			. "create_nsdl_popup_button('{$serverUrl}');"
        			. "</script>\n"
            	);
            	return true;
    		    break;
    	    default:
    	        break;
    	}
	}
  	return false;
}

/*
 * Response to actions for searchpopup
 */
function nsdlsearchActionHook( $action, $wgArticle ) {
    global $wgOut, $wgRequest;

    $title = $wgArticle->getTitle(); 
    $wgOut->setPageTitle("NSDL Search");

    $search_nsdl = new NSDLSearchExtension_SearchNSDL();
    $search_nsdl->query = $wgRequest->getVal('q');
    $search_nsdl->skip = $wgRequest->getVal('skip');
    
	try {
		$wgOut->addHTML( $search_nsdl->execute() );
		
	} catch (Exception $e) {
		/* 
		 * This will cause wiki processing to stop, 
		 * and the error to be reported 
		 */
		return $e->getMessage();
	}
    if ($action == 'nsdlsearch') {
       $wgOut->addHTML( 'The page name is ' . $title->getText() . ' and you are ' . $wgArticle->getUserText() );
    }
    return false;
}

/* 
 * Adds the Repository Manager to the list of special pages.  This is not the
 * usual way to do it, but apparently there is a MediaWiki bug as documented earlier
 */
function nspSetup() {
  global $wgMessageCache;
  $wgMessageCache->addMessage('searchresultsdisplay', 'NSDL Search Results');
}

?>