<?php

/* MediaWiki extension point for NDR page metadata 
 *
 * The contents enclosed in this tag are treated as NDR
 * metadata describing the wiki page itself.  If the papge is
 * published in the NDR as a resource, this extension
 * mediates the metadata that describes it in the NDR 
 *  
 * Copyright (c) 2008 by Cornell University (email : systems@nsdl.org)
 * The program is distributed under the Educational Community License. 
 * Details can be found in the LICENSE file of this distribution.
 * 
 */
require_once(dirname(__FILE__) . '/nsdl/ndr/NdrApi.php');
require_once(dirname(__FILE__) . '/nsdl/NDRExtension/URLNormalizer.php');
require_once(dirname(__FILE__) . '/nsdl/util/Properties.php');

$wgExtensionFunctions[] = "initNSDLSlugExtension";

$wgExtensionCredits['specialpage'][] = array (
	'name' => 'NSDL Slug Extension',
	'version' => '2007/06/04',
	'author' => 'Aaron Birkland',
	'url' => 'http://wiki.nsdl.org/index.php/Community:NSDLWiki',
	'description' => 'Identifies links that are NSDL resources and inserts a "slug" that links to the NSDL record of that page',
	
);

/* As per bug described in 
 * http://meta.wikimedia.org/w/index.php?title=Writing_a_new_special_page&oldid=545772 
 */
$wgExtensionFunctions[] = 'nsdlSlugSetup';

/* Register this extension with the appropriate hooks */
function initNSDLSlugExtension() {
	global $wgHooks;
	$wgHooks['OutputPageBeforeHTML'][] = 'filterSlugs';
}

function filterSlugs(& $out, & $text) {
	 global $nsdlResourcePath;
	 global $wgScriptPath;
	 global $wgJsMimeType;
	 $out->addScript( 
                "<script type=\"{$wgJsMimeType}\" src=\"{$wgScriptPath}{$nsdlResourcePath}/NSDLSlugExtension.js\">" .
                "</script>\n");
                
     $out->addHTML('<style><!--
.menu{
position:absolute;
border:1px solid black;
background-color:menu;
line-height:20px;
cursor:default;
z-index:100;
display:none;
}--></style>');
     $out->addHTML(SlugMenu::getAddMenu());
     $out->addHTML(SlugMenu::getEditMenu());
	$text = NSDLLinkFilter :: filterHTML($text);
	return true;
}

function nsdlSlugSetup() {
	global $wgMessageCache;
	$wgMessageCache->addMessage('nsdlslug', 'NSDL Slug');
}

class NSDLLinkFilter {
	private static $ndr;
	public static function filterHTML($html) {
		if (!isset(self::$ndr)) {
			self::$ndr = new ndr_NdrApi();
		}
		
		$match_regex = '~' .
			'<a' . // start the first div tag
		'[^>]*' . // filler
		'href=[\'"]' . // signals the start of the target url
		'([^\'"]*)' . // the target url
		'[\'"]' . // closing quote ends the target url
		'[^>]*' . // filler
		'>' . // end the opening tag
		'(.*)' . // the text
		'</a>' . // closing tag
		'~sUi'; // multi-line, caseless, not greedy

		try {
			return preg_replace_callback($match_regex, array('self', 'replaceLinks'), $html);
		} catch (exception $e) {
			/* If there's a problem, just return the un-slugged html. 
			 * We should probably log this somewhere!
			 */
			return $html;
		}
	}
	
	private static function replaceLinks($matches) {
		$url = $matches[1];
		/* Check, and fix, relative links */
		$url = URLNormalizer::normalize($url);
		
		try {
			$handle = self::$ndr->find_resource($url);
		} catch (exception $e) {
			/* If something is wrong, we should probably log it.  Since
			 * we don't want to "throw the baby out with the bathwater ", 
			 * we continue on at this point, and the current link will not
			 * be slugged
			 */
		}
		$aTag = '';
		$onClick = '';
		if (isset($handle)) {
			$slugURL = util_Properties::get_nsdl_landing_base_url() . $handle;
			// IE wants a space between the <a></a> tag for the NSDL slug image to dispay as a background in the css.
			$aTag = $matches[0] . "<a href=\"$slugURL\" class=\"nsdl_slug\"> </a>";
		} else {
			$aTag =  $matches[0];
			//$onClick = 'oncontextmenu="javascript:return slugMenuClick(event);"';
		}
		
		return "<span class=\"nsdlSlugContainer\" $onClick>" . $aTag . '</span>';
	}
}

class SlugMenu {

	public function getAddMenu() {
		return '<div id="slug-menu-new" class="menu"
	onmouseover="highlight(event)"
	onmouseout="dehighlight(event)" 
	onclick="editResource(event)">
 <div class="slug-menu-item" id="slug-menu-item-add"><a href="' . self::getPath() .'">Add to NSDL</a></div>
</div>';
	}
	
	public function getEditMenu() {
		return '<div id="slug-menu-existing" class="menu"
	onmouseover="highlight(event)"
	onmouseout="dehighlight(event)" 
	onclick="editResource(event)">
 <div class="slug-menu-item" id="slug-menu-item-view"><a href="'.self::getPath() .'">View in NSDL</a></div>
 <div class="slug-menu-item" id="slug-menu-item-edit"><a href="'.self::getPath() .'">Edit Metadata</a></div>
</div>';
	}
	private function getPath() {
		global $wgScriptPath;
		return '/' . $wgScriptPath . "index.php/Special:ReferencedResourceManager?action=edit&url=#";
	}
}

?>